==> App-GitHooks-Plugin-RequireTicketID-v1.0.0.tar.gz: App-GitHooks-Plugin-RequireTicketID-v1.0.0/README.md <==
App-GitHooks-Plugin-RequireTicketID
===================================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID.png?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID?branch=master)

App::GitHooks plugin to require a ticket ID in the commit message.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitHooks::Plugin::RequireTicketID


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitHooks-Plugin-RequireTicketID)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitHooks-Plugin-RequireTicketID)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitHooks-Plugin-RequireTicketID)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2013-2014 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> App-GitHooks-Plugin-RequireTicketID-v1.0.4.tar.gz: App-GitHooks-Plugin-RequireTicketID-v1.0.4/README.md <==
App-GitHooks-Plugin-RequireTicketID
===================================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID.svg?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID?branch=master)
[![Latest Version](https://img.shields.io/github/tag/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID.svg?style=flat)](https://metacpan.org/release/App-GitHooks-Plugin-RequireTicketID)

App::GitHooks plugin to require a ticket ID in the commit message.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitHooks::Plugin::RequireTicketID


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitHooks-Plugin-RequireTicketID/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitHooks-Plugin-RequireTicketID)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitHooks-Plugin-RequireTicketID)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitHooks-Plugin-RequireTicketID)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2013-2015 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
